@@ -483,6 +483,7 @@ class Activity(Window, gtk.Container):
         self._max_participants = 0
         self._invites_queue = []
         self._jobject = None
+        self._read_file_called = False
 
         self._session = _get_session()
         self._session.register(self)
@@ -603,7 +604,8 @@ class Activity(Window, gtk.Container):
         One commonly used canvas is gtk.ScrolledWindow
         """
         Window.set_canvas(self, canvas)
-        canvas.connect('map', self.__canvas_map_cb)
+        if not self._read_file_called:
+            canvas.connect('map', self.__canvas_map_cb)
 
     def __session_quit_requested_cb(self, session):
         self._quit_requested = True
@@ -617,8 +619,12 @@ class Activity(Window, gtk.Container):
         self._complete_close()
 
     def __canvas_map_cb(self, canvas):
-        if self._jobject and self._jobject.file_path:
+        logging.debug('Activity.__canvas_map_cb')
+        if self._jobject and self._jobject.file_path and \
+                not self._read_file_called:
             self.read_file(self._jobject.file_path)
+            self._read_file_called = True
+        canvas.disconnect_by_func(self.__canvas_map_cb)
 
     def __jobject_create_cb(self):
         pass
@@ -713,8 +719,14 @@ class Activity(Window, gtk.Container):
             self._jobject.destroy()
             self._jobject = None
 
-    def _get_preview(self):
+    def get_preview(self):
+        """Returns an image representing the state of the activity. Generally
+        this is what the user is seeing in this moment.
 
+        Activities can override this method, which should return a str with the
+        binary content of a png image with a width of 300 and a height of 225
+        pixels.
+        """
         if self.canvas is None or not hasattr(self.canvas, 'get_snapshot'):
             return None
         pixmap = self.canvas.get_snapshot((-1, -1, 0, 0))
@@ -770,7 +782,7 @@ class Activity(Window, gtk.Container):
             self.metadata['buddies_id'] = cjson.encode(buddies_dict.keys())
             self.metadata['buddies'] = cjson.encode(self._get_buddies())
 
-        preview = self._get_preview()
+        preview = self.get_preview()
         if preview is not None:
             self.metadata['preview'] = dbus.ByteArray(preview)
 
@@ -938,7 +950,7 @@ class Activity(Window, gtk.Container):
         if not skip_save:
             try:
                 self.save()
-            except Exception:
+            except:
                 logging.info(traceback.format_exc())
                 self._show_keep_failed_dialog()
                 return False
