@@ -145,7 +145,7 @@ class Palette(gtk.Window):
     # DEPRECATED: label is passed with the primary-text property, accel_path 
     # is set via the invoker property, and menu_after_content is not used
     def __init__(self, label=None, accel_path=None, menu_after_content=False,
-                 text_maxlen=0, **kwargs):
+                 text_maxlen=60, **kwargs):
 
         self.palette_state = self.PRIMARY
 
@@ -162,7 +162,7 @@ class Palette(gtk.Window):
         primary_box.show()
 
         self._icon_box = gtk.HBox()
-        self._icon_box.set_size_request(style.zoom(style.GRID_CELL_SIZE), -1)
+        self._icon_box.set_size_request(style.GRID_CELL_SIZE, -1)
         primary_box.pack_start(self._icon_box, expand=False)
 
         labels_box = gtk.VBox()
@@ -188,7 +188,7 @@ class Palette(gtk.Window):
 
         if text_maxlen > 0:
             self._secondary_label.set_max_width_chars(text_maxlen)
-            self._secondary_label.set_ellipsize(pango.ELLIPSIZE_MIDDLE)
+            self._secondary_label.set_ellipsize(pango.ELLIPSIZE_END)
 
         labels_box.pack_start(self._secondary_label, expand=True)
 
@@ -221,7 +221,7 @@ class Palette(gtk.Window):
         self.set_data('sugar-accel-group', accel_group)
         self.add_accel_group(accel_group)
 
-        primary_box.set_size_request(-1, style.zoom(style.GRID_CELL_SIZE)
+        primary_box.set_size_request(-1, style.GRID_CELL_SIZE
                                      - 2 * self.get_border_width())
 
 
@@ -355,6 +355,8 @@ class Palette(gtk.Window):
                                     setter=set_primary_text)
 
     def set_secondary_text(self, label):
+        if label is not None:
+            label = label.split('\n', 1)[0]
         self._secondary_text = label
 
         if label is None:
@@ -461,7 +463,7 @@ class Palette(gtk.Window):
                       2 * self.get_border_width()
 
         requisition.width = max(requisition.width,
-                                style.zoom(style.GRID_CELL_SIZE * 2),
+                                style.GRID_CELL_SIZE * 2,
                                 label_width,
                                 self._full_request[0])
 
